@@ -1653,7 +1653,7 @@ void CodeCharExpr(CodeState * cs, Char chr)
 
     // allocate the character expression
     litr = NewExpr(cs, EXPR_CHAR, sizeof(UInt));
-    WRITE_EXPR(cs, litr, 0, chr);
+    WRITE_EXPR(cs, litr, 0, (UChar)chr);
 
     // push the literal expression
     PushExpr( litr );
@@ -3184,7 +3184,7 @@ static Int InitKernel (
     MakeBagTypePublic(T_BODY);
 #endif
 
-    // allocate the statements and expressions stacks
+    // register global bags with the garbage collector
     InitGlobalBag(&CS(StackStat), "CS(StackStat)");
     InitGlobalBag(&CS(StackExpr), "CS(StackExpr)");
 
