@@ -134,6 +134,7 @@
 #endif
 
 #ifdef GAP_MEM_CHECK
+#include <stdio.h>
 #include <sys/mman.h>
 #endif
 
@@ -1138,9 +1139,9 @@ int RegisterAfterCollectFuncBags(TNumCollectFuncBags func)
 
 Int EnableMemCheck = 0;
 
-Int enableMemCheck(Char ** argv, void * dummy)
+int enableMemCheck(const char * argv[], void * dummy)
 {
-    SyFputs( "# Warning: --enableMemCheck causes SEVERE slowdowns. Starting GAP may take several days!\n", 3 );
+    fputs("# Warning: --enableMemCheck causes SEVERE slowdowns. Starting GAP may take several days!\n", stderr);
     EnableMemCheck = 1;
     return 1;
 }
@@ -1269,6 +1270,17 @@ void SetStackBottomBags(void * StackBottom)
 
 void InitBags(UInt initial_size, Bag * stack_bottom)
 {
+    // fix max if it is lower than min
+    if (SyStorMax != 0 && SyStorMax < SyStorMin) {
+        SyStorMax = SyStorMin;
+    }
+
+    // fix pool size if larger than SyStorKill
+    if (SyStorKill != 0 && SyAllocPool != 0 &&
+        SyAllocPool > 1024 * SyStorKill) {
+        SyAllocPool = SyStorKill * 1024;
+    }
+
     ClearGlobalBags();
 
     // install the allocator and the abort function
