@@ -164,7 +164,7 @@ EXPORT_INLINE UInt TNUM_BAG(Bag bag)
 **
 **      if (TEST_BAG_FLAG(obj, FLAG1 | FLAG2 ) == (FLAG1 | FLAG2)) ...
 **
-**  Similary, if you wish to test that FLAG1 is set and FLAG2 is not set,
+**  Similarly, if you wish to test that FLAG1 is set and FLAG2 is not set,
 **  use:
 **
 **      if (TEST_BAG_FLAG(obj, FLAG1 | FLAG2 ) == FLAG1) ...
@@ -388,8 +388,14 @@ void CHANGED_BAG(Bag b);
 
 extern Bag * YoungBags;
 extern Bag   ChangedBags;
+
+#ifdef GAP_KERNEL_DEBUG
+BOOL         InWorkspaceRestore(void);
+#endif
+
 EXPORT_INLINE void CHANGED_BAG(Bag bag)
 {
+    GAP_ASSERT(!InWorkspaceRestore());
     if (CONST_PTR_BAG(bag) <= YoungBags && LINK_BAG(bag) == bag) {
         LINK_BAG(bag) = ChangedBags;
         ChangedBags = bag;
@@ -418,7 +424,7 @@ EXPORT_INLINE void CHANGED_BAG(Bag bag)
 **
 **  It is probably a good idea to define symbolic constants  for all types in
 **  a  system wide   header  file,  e.g.,  'types.h', if   only  to avoid  to
-**  accidently use the same value for two different types.
+**  accidentally use the same value for two different types.
 **
 **  <size> is the size of the new bag in bytes and must be a value  between 0
 **  and $2^{32}-1$ (on 32 bit systems)  resp. $2^{48}-1$ (on 64 bit systems).
@@ -655,10 +661,11 @@ Bag  MakeBagReadOnly(Bag bag);
 **  function for a  type before it allocates  any  bag  of  that type.  It is
 **  probably best to install all marking functions before allocating any bag.
 **
-**  A marking function  is a function  that takes a  single  argument of type
-**  'Bag' and returns nothing, i.e., has return type 'void'.  Such a function
-**  must apply the function 'MarkBag' to each bag  identifier that  appears in
-**  the bag (see below).
+**  A marking function is a function that takes a two arguments, one of type
+**  'Bag' and one of type 'void *' and returns nothing, i.e., has return type
+**  'void'.  Such a function must apply the function 'MarkBag' to each bag
+**  identifier that appears in the bag (see below), passing on its 'void *'
+**  argument unchanged to 'MarkBag' as second argument.
 **
 **  Those functions are applied during the garbage  collection to each marked
 **  bag, i.e., bags  that are assumed to be  still live,  to also mark  their
@@ -667,7 +674,8 @@ Bag  MakeBagReadOnly(Bag bag);
 **
 **  {\Gasman} already provides several marking functions, see below.
 */
-typedef void (* TNumMarkFuncBags )( Bag bag );
+#define GAP_MARK_FUNC_WITH_REF 1
+typedef void (* TNumMarkFuncBags )( Bag bag, void * ref );
 void InitMarkFuncBags(UInt type, TNumMarkFuncBags mark_func);
 
 #if !defined(USE_THREADSAFE_COPYING) && !defined(USE_BOEHM_GC)
@@ -683,7 +691,7 @@ extern TNumMarkFuncBags TabMarkFuncBags[NUM_TYPES];
 **  simply returns.  For example   in  {\GAP} the  bags for   large  integers
 **  contain only the digits and no identifiers of bags.
 */
-void MarkNoSubBags(Bag bag);
+void MarkNoSubBags(Bag bag, void * ref);
 
 
 /****************************************************************************
@@ -697,10 +705,10 @@ void MarkNoSubBags(Bag bag);
 **  the indicated number as bag identifiers as their initial entries.
 **  These functions mark those subbags and return.
 */
-void MarkOneSubBags(Bag bag);
-void MarkTwoSubBags(Bag bag);
-void MarkThreeSubBags(Bag bag);
-void MarkFourSubBags(Bag bag);
+void MarkOneSubBags(Bag bag, void * ref);
+void MarkTwoSubBags(Bag bag, void * ref);
+void MarkThreeSubBags(Bag bag, void * ref);
+void MarkFourSubBags(Bag bag, void * ref);
 
 
 /****************************************************************************
@@ -719,14 +727,14 @@ void MarkFourSubBags(Bag bag);
 **  bag identifiers for the elements  of the  list or 0   if an entry has  no
 **  assigned value.
 */
-void MarkAllSubBags(Bag bag);
+void MarkAllSubBags(Bag bag, void * ref);
 
 
 /****************************************************************************
 **
 *F  MarkAllButFirstSubBags(<bag>) . . . .  marks all subbags except the first
 */
-void MarkAllButFirstSubBags(Bag bag);
+void MarkAllButFirstSubBags(Bag bag, void * ref);
 
 
 /****************************************************************************
@@ -743,11 +751,11 @@ void MarkAllButFirstSubBags(Bag bag);
 **  identifier.
 */
 #ifdef USE_BOEHM_GC
-EXPORT_INLINE void MarkBag( Bag bag )
+EXPORT_INLINE void MarkBag( Bag bag, void * ref )
 {
 }
 #else
-void MarkBag(Bag bag);
+void MarkBag(Bag bag, void * ref);
 #endif
 
 
@@ -758,7 +766,7 @@ void MarkBag(Bag bag);
 **  'MarkArrayOfBags' iterates over <count> all bags in the given array,
 **  and marks each bag using MarkBag.
 */
-extern void MarkArrayOfBags(const Bag array[], UInt count);
+extern void MarkArrayOfBags(const Bag array[], UInt count, void * ref);
 
 
 /****************************************************************************
