@@ -19,8 +19,6 @@
 void InstallEvalBoolFunc(Int, EvalBoolFunc);
 void InstallEvalExprFunc(Int, EvalExprFunc);
 void InstallExecStatFunc(Int, ExecStatFunc);
-void InstallPrintStatFunc(Int, PrintStatFunc);
-void InstallPrintExprFunc(Int, PrintExprFunc);
 
 
 /****************************************************************************
@@ -36,9 +34,6 @@ extern ExecStatFunc OriginalExecStatFuncsForHook[256];
 extern EvalExprFunc OriginalEvalExprFuncsForHook[256];
 extern EvalBoolFunc OriginalEvalBoolFuncsForHook[256];
 
-extern PrintStatFunc OriginalPrintStatFuncsForHook[256];
-extern PrintExprFunc OriginalPrintExprFuncsForHook[256];
-
 
 /****************************************************************************
 **
@@ -75,40 +70,21 @@ extern PrintExprFunc OriginalPrintExprFuncsForHook[256];
 
 struct InterpreterHooks {
     void (*visitStat)(Stat stat);
-    void (*visitInterpretedStat)(Int line, Int pos);
+    void (*visitInterpretedStat)(int fileid, int line);
     void (*enterFunction)(Obj func);
     void (*leaveFunction)(Obj func);
-    void (*registerStat)(Stat stat);
-    void (*registerInterpretedStat)(Int line, Int pos);
+    void (*registerStat)(int fileid, int line, int type);
+    void (*registerInterpretedStat)(int fileid, int line);
     const char * hookName;
 };
 
 
-enum { HookCount = 6 };
+enum { MAX_HOOK_COUNT = 6 };
 
-extern struct InterpreterHooks * activeHooks[HookCount];
+extern struct InterpreterHooks * activeHooks[MAX_HOOK_COUNT];
 
-Int ActivateHooks(struct InterpreterHooks * hook);
-Int DeactivateHooks(struct InterpreterHooks * hook);
-
-/****************************************************************************
-**
-** A struct to represent the hooks allowed into printing functions
-**
-**
-** This struct represents a list of functions which will be called whenever
-** a statement or expression is printed. They can be used to provide
-** simple customisation of printing. At the moment they are used by
-** profiling.c, to mark statements which have been executed.
-** Look at that code to get an idea how to use them.
-*/
-struct PrintHooks {
-    void (*printStatPassthrough)(Stat stat);
-    void (*printExprPassthrough)(Expr stat);
-};
-
-void ActivatePrintHooks(struct PrintHooks * hook);
-void DeactivatePrintHooks(struct PrintHooks * hook);
+BOOL ActivateHooks(struct InterpreterHooks * hook);
+BOOL DeactivateHooks(struct InterpreterHooks * hook);
 
 /****************************************************************************
 **
@@ -128,9 +104,8 @@ void DeactivatePrintHooks(struct PrintHooks * hook);
 
 #define GAP_HOOK_LOOP(member, ...)                                           \
     do {                                                                     \
-        Int                       i;                                         \
         struct InterpreterHooks * hook;                                      \
-        for (i = 0; i < HookCount; ++i) {                                    \
+        for (int i = 0; i < MAX_HOOK_COUNT; ++i) {                           \
             hook = activeHooks[i];                                           \
             if (hook && hook->member) {                                      \
                 (hook->member)(__VA_ARGS__);                                 \
@@ -154,16 +129,16 @@ EXPORT_INLINE void HookedLineOutFunction(Obj func)
     GAP_HOOK_LOOP(leaveFunction, func);
 }
 
-EXPORT_INLINE void RegisterStatWithHook(Stat func)
+EXPORT_INLINE void RegisterStatWithHook(int fileid, int line, int type)
 {
-    GAP_HOOK_LOOP(registerStat, func);
+    GAP_HOOK_LOOP(registerStat, fileid, line, type);
 }
 
-EXPORT_INLINE void InterpreterHook(Int file, Int line, Int skipped)
+EXPORT_INLINE void InterpreterHook(int fileid, int line, Int skipped)
 {
-    GAP_HOOK_LOOP(registerInterpretedStat, file, line);
+    GAP_HOOK_LOOP(registerInterpretedStat, fileid, line);
     if (!skipped) {
-        GAP_HOOK_LOOP(visitInterpretedStat, file, line);
+        GAP_HOOK_LOOP(visitInterpretedStat, fileid, line);
     }
 }
 
