@@ -8,22 +8,22 @@
 **  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include "hpc/thread.h"
+#include "thread.h"
 
-#include "code.h"
-#include "error.h"
-#include "fibhash.h"
-#include "gapstate.h"
-#include "gvars.h"
-#include "modules.h"
-#include "plist.h"
-#include "stats.h"
-#include "stringobj.h"
-#include "vars.h"
+#include "../code.h"
+#include "../error.h"
+#include "../fibhash.h"
+#include "../gapstate.h"
+#include "../gvars.h"
+#include "../modules.h"
+#include "../plist.h"
+#include "../stats.h"
+#include "../stringobj.h"
+#include "../vars.h"
 
-#include "hpc/guards.h"
-#include "hpc/misc.h"
-#include "hpc/threadapi.h"
+#include "guards.h"
+#include "misc.h"
+#include "threadapi.h"
 
 #include <errno.h>
 #include <pthread.h>
@@ -299,13 +299,13 @@ void InitMainThread(void)
     TLS(CountActive) = 1;
 }
 
-static NOINLINE void RunThreadedMain2(int (*mainFunction)(int, char **),
+static NOINLINE void RunThreadedMain2(int (*mainFunction)(int, const char **),
                              int     argc,
-                             char ** argv);
+                             const char ** argv);
 
-void RunThreadedMain(int (*mainFunction)(int, char **),
+void RunThreadedMain(int (*mainFunction)(int, const char **),
                      int     argc,
-                     char ** argv)
+                     const char ** argv)
 {
 #ifndef USE_NATIVE_TLS
 #ifdef STACK_GROWS_UP
@@ -335,9 +335,9 @@ void RunThreadedMain(int (*mainFunction)(int, char **),
     RunThreadedMain2(mainFunction, argc, argv);
 }
 
-static void RunThreadedMain2(int (*mainFunction)(int, char **),
+static void RunThreadedMain2(int (*mainFunction)(int, const char **),
                              int     argc,
-                             char ** argv)
+                             const char ** argv)
 {
     int                    i;
     static pthread_mutex_t main_thread_mutex;
