@@ -2614,8 +2614,8 @@ static Obj FuncIS_PROBAB_PRIME_INT(Obj self, Obj n, Obj reps)
 **  InitRandomMT.
 **
 **  Implementation details are a bit tricky to obtain the same random
-**  integers on 32 bit and 64 bit machines (which have different long
-**  integer digit lengths and different ranges of small integers).
+**  integers on 32 bit and 64 bit machines (which have different ranges of
+**  integers).
 **
 */
 static Obj FuncRandomIntegerMT(Obj self, Obj mtstr, Obj nrbits)
@@ -2641,9 +2641,9 @@ static Obj FuncRandomIntegerMT(Obj self, Obj mtstr, Obj nrbits)
        res = INTOBJ_INT((Int)(nextrandMT_int32(mt) & ((UInt4)-1 >> (32-n))));
      }
      else {
-       unsigned long  rd;
+       UInt8 rd;
        rd = nextrandMT_int32(mt);
-       rd += (unsigned long) ((UInt4) nextrandMT_int32(mt) &
+       rd += (UInt8) ((UInt4) nextrandMT_int32(mt) &
                               ((UInt4)-1 >> (64-n))) << 32;
        res = INTOBJ_INT((Int)rd);
      }
