@@ -35,8 +35,8 @@
 
 #include "config.h"
 
-#include <stdio.h>
-#include <stdlib.h>
+#include <stdio.h>      // for snprintf
+#include <stdlib.h>     // for strtod
 
 
 #define RequireMacFloat(funcname, op) \
@@ -653,7 +653,7 @@ static Int InitKernel (
     // equivalents
 
     // Anything else, like mixed ops with rationals, we can leave to the
-    // library at least for a while */
+    // library at least for a while
 
     return 0;
 }
