@@ -32,16 +32,14 @@
 #include "hpc/guards.h"
 #include "hpc/thread.h"
 #include "hpc/traverse.h"
+#include <stdio.h>      // for sprintf
+#include <stdlib.h>     // for getenv
 #endif
 
 #if defined(USE_THREADSAFE_COPYING)
 #include "hpc/traverse.h"
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-
-
 enum {
     MAXPRINTDEPTH = 64,
 };
@@ -50,15 +48,8 @@ static ModuleStateOffset ObjectsStateOffset = -1;
 
 typedef struct {
     UInt  PrintObjDepth;
-#ifdef HPCGAP
-    Obj   PrintObjThissObj;
-    Obj * PrintObjThiss;
-    Obj   PrintObjIndicesObj;
-    Int * PrintObjIndices;
-#else
     Obj   PrintObjThiss[MAXPRINTDEPTH];
     Int   PrintObjIndices[MAXPRINTDEPTH];
-#endif
 
     // This variable is used to allow a ViewObj method to call PrintObj on the
     // same object without triggering use of '~'. It contains one of the
@@ -940,18 +931,20 @@ static void PrintInaccessibleObject(Obj obj)
 }
 #endif
 
-#ifdef HPCGAP
-// On-demand creation of the PrintObj stack
-static void InitPrintObjStack(ObjectsModuleState * os)
+static void PRINT_PATH(Obj obj, Int idx)
 {
-    if (!os->PrintObjThiss) {
-        os->PrintObjThissObj = NewBag(T_DATOBJ, MAXPRINTDEPTH*sizeof(Obj)+sizeof(Obj));
-        os->PrintObjThiss = ADDR_OBJ(os->PrintObjThissObj)+1;
-        os->PrintObjIndicesObj = NewBag(T_DATOBJ, MAXPRINTDEPTH*sizeof(Int)+sizeof(Obj));
-        os->PrintObjIndices = (Int *)(ADDR_OBJ(os->PrintObjIndicesObj)+1);
+    UInt tnum = TNUM_OBJ(obj);
+    if (IS_PREC(obj)) {
+        Pr(".%I", (Int)NAME_RNAM(idx), 0);
+    }
+    else if (FIRST_LIST_TNUM <= tnum && tnum <= LAST_LIST_TNUM) {
+        Pr("[%d]", idx, 0);
+    }
+    else {
+        ErrorQuit("Panic: tried to print a path of unsupported type '%s'",
+                  (Int)tnum, 0);
     }
 }
-#endif
 
 /****************************************************************************
 **
@@ -970,10 +963,6 @@ void PrintObj(Obj obj)
 
     ObjectsModuleState * os = &MODULE_STATE(Objects);
 
-#ifdef HPCGAP
-    InitPrintObjStack(os);
-#endif
-
     // First check if <obj> is actually the current object being viewed, since
     // ViewObj(<obj>) may result in a call to PrintObj(<obj>); in that case,
     // we should not put <obj> on the print stack
@@ -995,6 +984,9 @@ void PrintObj(Obj obj)
     // dispatch to the appropriate printing function
     else if (os->PrintObjDepth < MAXPRINTDEPTH) {
 
+        Obj oldThis = os->PrintObjThiss[os->PrintObjDepth];
+        Int oldIndx = os->PrintObjIndices[os->PrintObjDepth];
+
         // push obj on the stack
         os->PrintObjThiss[os->PrintObjDepth] = obj;
         os->PrintObjIndices[os->PrintObjDepth] = 0;
@@ -1007,6 +999,8 @@ void PrintObj(Obj obj)
 
         // pop <obj> from the stack
         os->PrintObjDepth--;
+        os->PrintObjThiss[os->PrintObjDepth] = oldThis;
+        os->PrintObjIndices[os->PrintObjDepth] = oldIndx;
     }
     else {
         Pr("\nprinting stopped, too many recursion levels!\n", 0, 0);
@@ -1095,10 +1089,6 @@ void ViewObj(Obj obj)
 
     ObjectsModuleState * os = &MODULE_STATE(Objects);
 
-#ifdef HPCGAP
-    InitPrintObjStack(os);
-#endif
-
     // print the path if <obj> is on the stack
     if (IS_ON_PRINT_STACK(os, obj)) {
         Pr("~", 0, 0);
@@ -1110,6 +1100,9 @@ void ViewObj(Obj obj)
     // dispatch to the appropriate viewing function
     else if (os->PrintObjDepth < MAXPRINTDEPTH) {
 
+        Obj oldThis = os->PrintObjThiss[os->PrintObjDepth];
+        Int oldIndx = os->PrintObjIndices[os->PrintObjDepth];
+
         // push obj on the stack
         os->PrintObjThiss[os->PrintObjDepth] = obj;
         os->PrintObjIndices[os->PrintObjDepth] = 0;
@@ -1122,6 +1115,8 @@ void ViewObj(Obj obj)
 
         // pop <obj> from the stack
         os->PrintObjDepth--;
+        os->PrintObjThiss[os->PrintObjDepth] = oldThis;
+        os->PrintObjIndices[os->PrintObjDepth] = oldIndx;
     }
     else {
         Pr("\nviewing stopped, too many recursion levels!\n", 0, 0);
@@ -1140,25 +1135,6 @@ static Obj FuncVIEW_OBJ(Obj self, Obj obj)
 }
 
 
-/****************************************************************************
-**
-*V  PrintPathFuncs[<type>]  . . . . . . printer for subobjects of type <type>
-**
-**  'PrintPathFuncs'  is   the   dispatch table  that     contains for  every
-**  appropriate type of objects a pointer to  the path printer for objects of
-**  that type.  The path  printer is the function '<func>(<obj>,<indx>)' that
-**  should be  called  to print  the  selector   that selects  the  <indx>-th
-**  subobject of the object <obj> of this type.
-*/
-void (* PrintPathFuncs [ LAST_REAL_TNUM /* +PRINTING */+1 ])( Obj obj, Int indx );
-
-static void PrintPathError(Obj obj, Int indx)
-{
-    ErrorQuit("Panic: tried to print a path of unsupported type '%s'",
-              (Int)TNAM_OBJ(obj), 0);
-}
-
-
 /****************************************************************************
 **
 *F  TypeComObj( <obj> ) . . . . . . . . . . function version of 'TYPE_COMOBJ'
@@ -2169,12 +2145,6 @@ static Int InitKernel (
         PrintObjFuncs[ t ] = PrintObjObject;
     }
 
-    // enter 'PrintUnknownObj' in the dispatching tables
-    for ( t = FIRST_REAL_TNUM; t <= LAST_REAL_TNUM; t++ ) {
-        assert(PrintPathFuncs[ t ] == 0);
-        PrintPathFuncs[ t ] = PrintPathError;
-    }
-
 #ifdef GAP_ENABLE_SAVELOAD
     // enter 'SaveObjError' and 'LoadObjError' for all types initially
     for ( t = FIRST_REAL_TNUM;  t <= LAST_REAL_TNUM;  t++ ) {
