@@ -109,22 +109,13 @@ void InterruptExecStat(void);
 void PrintStat(Stat stat);
 
 
+void InstallPrintStatFunc(unsigned int pos, PrintStatFunc f);
+
+
 /****************************************************************************
 **
-*V  PrintStatFuncs[<type>]  . .  print function for statements of type <type>
-**
-**  'PrintStatFuncs' is the dispatching table that contains for every type of
-**  statements a pointer to the  printer for statements  of this type,  i.e.,
-**  the function that should be called to print statements of this type.
+*F  ClearError()  . . . . . . . . . . . . . .  reset execution and error flag
 */
-extern PrintStatFunc PrintStatFuncs[256];
-
-
-/****************************************************************************
- **
- *F  ClearError()  . . . . . . . . . . . . . .  reset execution and error flag
- *
- */
 void ClearError(void);
 
 
