@@ -434,11 +434,11 @@ char SyFileType(const Char * path);
 
 /****************************************************************************
 **
-*F  void getwindowsize( void )  . probe the OS for the window size and
+*F  void InitWindowSize( void )  . probe the OS for the window size and
 **                               set SyNrRows and SyNrCols accordingly
 */
 
-void getwindowsize(void);
+void InitWindowSize(void);
 
 /****************************************************************************
 **
@@ -484,6 +484,9 @@ void * SyMemmove(void * dst, const void * src, size_t size);
 // initialization.
 void InitSysFiles(void);
 
+//
+void InitReadline(void);
+
 /****************************************************************************
 **
 *F  InitInfoSysFiles()  . . . . . . . . . . . . . . . table of init functions
