@@ -23,12 +23,11 @@
 
 #ifdef GAP_MEM_CHECK
 #include <fcntl.h>
+#include <stdlib.h>     // for qsort
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
+#include <stdio.h>      // for fputs
+#include <unistd.h>     // for ftruncate, getpid, unlink, sbrk, sysconf
 
 #ifdef HAVE_MADVISE
 #include <sys/mman.h>
@@ -36,6 +35,8 @@
 
 #ifdef HAVE_VM_ALLOCATE
 #include <mach/mach.h>
+#elif defined(HAVE_SBRK)
+#include <string.h>     // for memset
 #endif
 
 
@@ -301,8 +302,8 @@ int SyTryToIncreasePool(void)
 
 static void *SyMMapStart = NULL;   // Start of mmap'ed region for POOL
 static void *SyMMapEnd;            // End of mmap'ed region for POOL
-static void *SyMMapAdvised;        /* We have already advised about non-usage
-                                      up to here. */
+static void *SyMMapAdvised;        // We have already advised about non-usage
+                                   // up to here.
 
 void SyMAdviseFree(void)
 {
@@ -418,9 +419,7 @@ static int SyTryToIncreasePool(void)
 static void SyInitialAllocPool(void)
 {
 #ifdef HAVE_SYSCONF
-#ifdef _SC_PAGESIZE
    pagesize = sysconf(_SC_PAGESIZE);
-#endif
 #endif
    // Otherwise we take the default of 4k as pagesize.
 
