@@ -21,6 +21,16 @@
 #include <stdlib.h>
 
 
+/****************************************************************************
+**
+*V  SyDefaultRootPath
+**
+**  Default initial root path. Default is the current directory, if we have
+**  no other idea, for backwards compatibility.
+*/
+char SyDefaultRootPath[GAP_PATH_MAX] = "./";
+
+
 /****************************************************************************
 **
 *V  SyGapRootPaths  . . . . . . . . . . . . . . . . . . . array of root paths
