@@ -22,22 +22,22 @@ size_t gap_strlcpy(char * dst, const char * src, size_t len)
     if (len > 0) {
         // Copy up to len-1 bytes (reserve one for the terminating zero).
         while (--len > 0) {
-            /* Copy from src to dst; if we reach the string end, we are
-               done and can simply return the total source string length */
+            // Copy from src to dst; if we reach the string end, we are
+            // done and can simply return the total source string length
             if ((*dst++ = *src++) == 0) {
                 // return length of source string without the zero byte
                 return src - orig_src - 1;
             }
         }
 
-        /* If we got here, then we used up the whole buffer and len is zero.
-           We must make sure to terminate the destination string. */
+        // If we got here, then we used up the whole buffer and len is zero.
+        // We must make sure to terminate the destination string.
         *dst = 0;
     }
 
-    /* in the end, we must return the length of the source string, no
-       matter whether we completely copied or not; so advance src
-       till its terminator is reached */
+    // in the end, we must return the length of the source string, no
+    // matter whether we completely copied or not; so advance src
+    // till its terminator is reached
     while (*src++)
         ;
 
@@ -56,14 +56,14 @@ size_t gap_strlcat(char * dst, const char * src, size_t len)
         len--;
     }
 
-    /* We can only append anything if there is free space left in the
-       destination buffer. */
+    // We can only append anything if there is free space left in the
+    // destination buffer.
     if (len > 0) {
         // One byte goes away for the terminating zero.
         len--;
 
-        /* Do the actual work and append from src to dst, until we either
-           appended everything, or reached the dst buffer's end. */
+        // Do the actual work and append from src to dst, until we either
+        // appended everything, or reached the dst buffer's end.
         while (*src != 0 && len > 0) {
             *dst++ = *src++;
             len--;
