@@ -47,7 +47,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
-#include <unistd.h>
+#include <unistd.h>     // for sysconf
 
 #include <sys/stat.h>
 
@@ -77,11 +77,11 @@ UInt SyCTRD;
 *V  SyCompileName . . . . . . . . . . . . . . . . . . . . . .  with this name
 *V  SyCompileMagic1 . . . . . . . . . . . . . . . . . . and this magic string
 */
-Int SyCompilePlease;
-Char * SyCompileOutput;
-Char * SyCompileInput;
-Char * SyCompileName;
-Char * SyCompileMagic1;
+BOOL SyCompilePlease;
+const char * SyCompileOutput;
+const char * SyCompileInput;
+const char * SyCompileName;
+const char * SyCompileMagic1;
 
 
 /****************************************************************************
@@ -107,6 +107,7 @@ static Char DotGapPath[GAP_PATH_MAX];
 */
 static Int IgnoreGapRC;
 
+
 /****************************************************************************
 **
 *V  SyLineEdit  . . . . . . . . . . . . . . . . . . . .  support line editing
@@ -117,6 +118,7 @@ static Int IgnoreGapRC;
 */
 UInt SyLineEdit;
 
+
 /****************************************************************************
 **
 *V  SyUseReadline   . . . . . . . . . . . . . . . . . .  support line editing
@@ -125,6 +127,7 @@ UInt SyLineEdit;
 */
 UInt SyUseReadline;
 
+
 /****************************************************************************
 **
 *V  SyNrCols  . . . . . . . . . . . . . . . . . .  length of the output lines
@@ -137,13 +140,12 @@ UInt SyUseReadline;
 **  'Pr' uses this to decide where to insert a <newline> on the output lines.
 **  'SyRead' uses it to decide when to start scrolling the echoed input line.
 **
-**  See also getwindowsize() below.
-**
-**  Put in this package because the command line processing takes place here.
+**  See also InitWindowSize().
 */
 UInt SyNrCols;
 UInt SyNrColsLocked;
 
+
 /****************************************************************************
 **
 *V  SyNrRows  . . . . . . . . . . . . . . . . . number of lines on the screen
@@ -153,13 +155,12 @@ UInt SyNrColsLocked;
 **  Per default this is 24, which is the  usual  size  of  terminal  screens.
 **  It can be changed with the '-y' option for larger terminals or  printers.
 **
-**  'SyHelp' uses this to decide where to stop with '-- <space> for more --'.
-**
-**  See also getwindowsize() below.
+**  See also InitWindowSize().
 */
 UInt SyNrRows;
 UInt SyNrRowsLocked;
 
+
 /****************************************************************************
 **
 *V  SyQuiet . . . . . . . . . . . . . . . . . . . . . . . . . suppress prompt
@@ -175,17 +176,26 @@ UInt SyNrRowsLocked;
 */
 UInt SyQuiet;
 
+
 /****************************************************************************
 **
 *V  SyQuitOnBreak . . . . . . . . . . exit GAP instead of entering break loop
+**
+**  'SyQuitOnBreak' determines whether GAP should quit (with non-zero return
+**  value) instead of entering the break loop.
+**
+**  False by default, can be changed with the '--quitonbreak' option.
+**
+**  Put in this package because the command line processing takes place here.
 */
 UInt SyQuitOnBreak;
 
+
 /****************************************************************************
 **
 *V  SyRestoring . . . . . . . . . . . . . . . . . . . . restoring a workspace
 **
-**  `SyRestoring' determines whether GAP is restoring a workspace or not.  If
+**  'SyRestoring' determines whether GAP is restoring a workspace or not.  If
 **  it is zero no restoring should take place otherwise it holds the filename
 **  of a workspace to restore.
 **
@@ -199,7 +209,7 @@ Char * SyRestoring;
 **
 *V  SyInitializing                               set to 1 during library init
 **
-**  `SyInitializing' is set to 1 during the library initialization phase of
+**  'SyInitializing' is set to 1 during the library initialization phase of
 **  startup. It suppresses some behaviours that may not be possible so early
 **  such as homogeneity tests in the plist code.
 */
@@ -207,13 +217,6 @@ Char * SyRestoring;
 UInt SyInitializing;
 
 
-/****************************************************************************
-**
-*V  SyLoadSystemInitFile  . . . . . . should GAP load 'lib/init.g' at startup
-*/
-Int SyLoadSystemInitFile = 1;
-
-
 /****************************************************************************
 **
 *V  SyUseModule . . . . . . . . . check for static modules in 'READ_GAP_ROOT'
@@ -249,13 +252,12 @@ UInt SyWindow;
 **  If ret is 0 'SyExit' should signal to a calling process that all is  ok.
 **  If ret is 1 'SyExit' should signal a  failure  to  the  calling process.
 */
-void SyExit (
-    UInt                ret )
+void SyExit(UInt ret)
 {
 #ifdef USE_JULIA_GC
     jl_atexit_hook(ret);
 #endif
-    exit( (int)ret );
+    exit((int)ret);
 }
 
 
@@ -285,19 +287,6 @@ const Char * SyDotGapPath(void)
 }
 
 
-/****************************************************************************
-**
-*F  InitSystem( <argc>, <argv> )  . . . . . . . . . initialize system package
-**
-**  'InitSystem' is called very early during the initialization from  'main'.
-**  It is passed the command line array  <argc>, <argv>  to look for options.
-**
-**  For UNIX it initializes the default files 'stdin', 'stdout' and 'stderr',
-**  installs the handler 'syAnswerIntr' to answer the user interrupts
-**  '<ctr>-C', scans the command line for options, sets up the GAP root paths,
-**  locates the '.gaprc' file (if any), and more.
-*/
-
 #if defined(USE_GASMAN) || defined(USE_BOEHM_GC)
 typedef struct { Char symbol; UInt value; } sizeMultiplier;
 
@@ -323,7 +312,7 @@ static const UInt maxmem = 15000000000000000000UL;
 static const UInt maxmem = 4000000000UL;
 #endif
 
-static BOOL ParseMemory(Char * s, UInt *result)
+static BOOL ParseMemory(const char * s, UInt * result)
 {
     char * end;
     const double size = strtod(s, &end);
@@ -362,16 +351,25 @@ err:
 
 #endif
 
+static void usage(void)
+{
+    fputs("usage: gap [OPTIONS] [FILES]\n", stderr);
+    fputs("       use '-h' option to get help.\n", stderr);
+    fputs("\n", stderr);
+    SyExit(1);
+}
+
 struct optInfo {
-  Char shortkey;
-  Char longkey[50];
-  Int (*handler)(Char **, void *);
-  void *otherArg;
-  UInt minargs;
+    int phase;
+    char shortkey;
+    char longkey[50];
+    int (*handler)(const char * argv[], void *);
+    void *otherArg;
+    UInt minargs;
 };
 
 
-static Int toggle( Char ** argv, void *Variable )
+static int toggle(const char * argv[], void * Variable)
 {
   UInt * variable = (UInt *) Variable;
   *variable = !*variable;
@@ -379,11 +377,11 @@ static Int toggle( Char ** argv, void *Variable )
 }
 
 #ifdef HPCGAP
-static Int storePosInteger( Char **argv, void *Where )
+static int storePosInteger(const char * argv[], void * Where)
 {
   UInt *where = (UInt *)Where;
   UInt n;
-  Char *p = argv[0];
+  const char *p = argv[0];
   n = 0;
   while (IsDigit(*p)) {
     n = n * 10 + (*p-'0');
@@ -391,7 +389,7 @@ static Int storePosInteger( Char **argv, void *Where )
   }
   if (p == argv[0] || *p || n == 0) {
       fputs("Argument not a positive integer\n", stderr);
-      return -1;
+      usage();
   }
   *where = n;
   return 1;
@@ -399,38 +397,38 @@ static Int storePosInteger( Char **argv, void *Where )
 #endif
 
 #ifdef GAP_ENABLE_SAVELOAD
-static Int storeString( Char **argv, void *Where )
+static int storeString(const char * argv[], void * Where)
 {
-  Char **where = (Char **)Where;
-  *where = argv[0];
-  return 1;
+    const char ** where = (const char **)Where;
+    *where = argv[0];
+    return 1;
 }
 #endif
 
 #ifdef USE_GASMAN
-static Int storeMemory( Char **argv, void *Where )
+static int storeMemory(const char * argv[], void * Where)
 {
     UInt * where = (UInt *)Where;
     if (!ParseMemory(argv[0], where))
-        return -1;
+        usage();
     return 1;
 }
 #endif
 
 #if defined(USE_GASMAN) || defined(USE_BOEHM_GC)
-static Int storeMemory2( Char **argv, void *Where )
+static int storeMemory2(const char * argv[], void * Where)
 {
     UInt * where = (UInt *)Where;
     if (!ParseMemory(argv[0], where))
-        return -1;
+        usage();
     *where /= 1024;
     return 1;
 }
 #endif
 
-static Int processCompilerArgs( Char **argv, void * dummy)
+static int processCompilerArgs(const char * argv[], void * dummy)
 {
-    SyCompilePlease = 1;
+    SyCompilePlease = TRUE;
     SyCompileOutput = argv[0];
     SyCompileInput = argv[1];
     SyCompileName = argv[2];
@@ -439,21 +437,21 @@ static Int processCompilerArgs( Char **argv, void * dummy)
 }
 
 #ifdef GAP_ENABLE_SAVELOAD
-static Int unsetString( Char **argv, void *Where)
+static int unsetString(const char * argv[], void * Where)
 {
   *(Char **)Where = (Char *)0;
   return 0;
 }
 #endif
 
-static Int forceLineEditing( Char **argv,void *Level)
+static int forceLineEditing(const char * argv[], void * Level)
 {
   UInt level = (UInt)Level;
   SyLineEdit = level;
   return 0;
 }
 
-static Int setGapRootPath( Char **argv, void *Dummy)
+static int setGapRootPath(const char * argv[], void * Dummy)
 {
   SySetGapRootPath( argv[0] );
   return 1;
@@ -463,21 +461,22 @@ static Int setGapRootPath( Char **argv, void *Dummy)
 #ifndef GAP_MEM_CHECK
 // Provide stub with helpful error message
 
-static Int enableMemCheck(Char ** argv, void * dummy)
+static int enableMemCheck(const char * argv[], void * dummy)
 {
-    SyFputs( "# Error: --enableMemCheck not supported by this copy of GAP\n", 3);
-    SyFputs( "  pass --enable-memory-checking to ./configure\n", 3 );
+    fputs("# Error: --enableMemCheck not supported by this copy of GAP\n", stderr);
+    fputs("  pass --enable-memory-checking to ./configure\n", stderr);
     SyExit(2);
 }
 #endif
 
 
-static Int printVersion(Char ** argv, void * dummy)
+static int printVersion(const char * argv[], void * dummy)
 {
-    SyFputs("GAP ", 1);
-    SyFputs(SyBuildVersion, 1);
-    SyFputs(" built on ", 1);
-    SyFputs(SyBuildDateTime, 1);
+    fputs("GAP ", stdout);
+    fputs(SyBuildVersion, stdout);
+    fputs(" built on ", stdout);
+    fputs(SyBuildDateTime, stdout);
+    fputs("\n", stdout);
     SyExit(0);
 }
 
@@ -488,73 +487,66 @@ static Int printVersion(Char ** argv, void * dummy)
 // These options must be kept in sync with those in system.g, so the help
 // output is correct
 static const struct optInfo options[] = {
-  { 'C',  "", processCompilerArgs, 0, 4}, // must handle in kernel
-  { 'D',  "debug-loading", toggle, &SyDebugLoading, 0}, // must handle in kernel
+  { 0, 'C',  "", processCompilerArgs, 0, 4}, // must handle in kernel
+  { 0, 'D',  "debug-loading", toggle, &SyDebugLoading, 0}, // must handle in kernel
 #if defined(USE_GASMAN) || defined(USE_BOEHM_GC)
-  { 'K',  "maximal-workspace", storeMemory2, &SyStorKill, 1}, // could handle from library with new interface
+  { 0, 'K',  "maximal-workspace", storeMemory2, &SyStorKill, 1}, // could handle from library with new interface
 #endif
 #ifdef GAP_ENABLE_SAVELOAD
-  { 'L', "", storeString, &SyRestoring, 1}, // must be handled in kernel
-  { 'R', "", unsetString, &SyRestoring, 0}, // kernel
+  { 0, 'L', "", storeString, &SyRestoring, 1}, // must be handled in kernel
+  { 0, 'R', "", unsetString, &SyRestoring, 0}, // kernel
 #endif
-  { 'M', "", toggle, &SyUseModule, 0}, // must be handled in kernel
-  { 'e', "", toggle, &SyCTRD, 0 }, // kernel
-  { 'f', "", forceLineEditing, (void *)2, 0 }, // probably library now
-  { 'E', "", toggle, &SyUseReadline, 0 }, // kernel
-  { 'l', "roots", setGapRootPath, 0, 1}, // kernel
+  { 0, 'M', "", toggle, &SyUseModule, 0}, // must be handled in kernel
+  { 0, 'e', "", toggle, &SyCTRD, 0 }, // kernel
+  { 0, 'f', "", forceLineEditing, (void *)2, 0 }, // probably library now
+  { 0, 'E', "", toggle, &SyUseReadline, 0 }, // kernel
+  { 1, 'l', "roots", setGapRootPath, 0, 1}, // kernel
 #ifdef USE_GASMAN
-  { 'm', "", storeMemory2, &SyStorMin, 1 }, // kernel
+  { 0, 'm', "", storeMemory2, &SyStorMin, 1 }, // kernel
 #endif
-  { 'r', "", toggle, &IgnoreGapRC, 0 }, // kernel
+  { 0, 'r', "", toggle, &IgnoreGapRC, 0 }, // kernel
 #ifdef USE_GASMAN
-  { 's', "", storeMemory, &SyAllocPool, 1 }, // kernel
+  { 0, 's', "", storeMemory, &SyAllocPool, 1 }, // kernel
 #endif
-  { 'n', "", forceLineEditing, 0, 0}, // prob library
+  { 0, 'n', "", forceLineEditing, 0, 0}, // prob library
 #ifdef USE_GASMAN
-  { 'o', "", storeMemory2, &SyStorMax, 1 }, // library with new interface
+  { 0, 'o', "", storeMemory2, &SyStorMax, 1 }, // library with new interface
 #endif
-  { 'p', "", toggle, &SyWindow, 0 }, // ??
-  { 'q', "", toggle, &SyQuiet, 0 }, // ??
+  { 0, 'p', "", toggle, &SyWindow, 0 }, // ??
+  { 0, 'q', "quiet", toggle, &SyQuiet, 0 }, // ??
 #ifdef HPCGAP
-  { 'S', "", toggle, &ThreadUI, 0 }, // Thread UI
-  { 'Z', "", toggle, &DeadlockCheck, 0 }, // Deadlock prevention
-  { 'P', "", storePosInteger, &SyNumProcessors, 1 }, // number of CPUs
-  { 'G', "", storePosInteger, &SyNumGCThreads, 1 }, // number of GC threads
-  { 0  , "single-thread", toggle, &SingleThreadStartup, 0 }, // startup with one thread only
+  { 0, 'S', "", toggle, &ThreadUI, 0 }, // Thread UI
+  { 0, 'Z', "", toggle, &DeadlockCheck, 0 }, // Deadlock prevention
+  { 0, 'P', "", storePosInteger, &SyNumProcessors, 1 }, // number of CPUs
+  { 0, 'G', "", storePosInteger, &SyNumGCThreads, 1 }, // number of GC threads
+  { 0, 0  , "single-thread", toggle, &SingleThreadStartup, 0 }, // startup with one thread only
 #endif
   // The following options must be handled in the kernel so they are set up before loading the library
-  { 0  , "prof", enableProfilingAtStartup, 0, 1},    // enable profiling at startup
-  { 0  , "memprof", enableMemoryProfilingAtStartup, 0, 1 }, // enable memory profiling at startup
-  { 0  , "cover", enableCodeCoverageAtStartup, 0, 1}, // enable code coverage at startup
-  { 0  , "quitonbreak", toggle, &SyQuitOnBreak, 0}, // Quit GAP if we enter the break loop
-  { 0  , "enableMemCheck", enableMemCheck, 0, 0 },
-  { 0  , "version", printVersion, 0, 0 },
-  { 0, "", 0, 0, 0}};
+  { 0, 0  , "prof", enableProfilingAtStartup, 0, 1},    // enable profiling at startup
+  { 0, 0  , "memprof", enableMemoryProfilingAtStartup, 0, 1 }, // enable memory profiling at startup
+  { 0, 0  , "cover", enableCodeCoverageAtStartup, 0, 1}, // enable code coverage at startup
+  { 0, 0  , "quitonbreak", toggle, &SyQuitOnBreak, 0}, // Quit GAP if we enter the break loop
+  { 0, 0  , "enableMemCheck", enableMemCheck, 0, 0 },
+  { 0, 0  , "version", printVersion, 0, 0 },
+  { 0, 0, "", 0, 0, 0}};
 
 
-Char ** SyOriginalArgv;
-UInt SyOriginalArgc;
-
-
-
-void InitSystem (
-    Int                 argc,
-    Char *              argv [],
-    UInt                handleSignals )
+static void InitSysOpts(void)
 {
-    UInt                i;             // loop variable
-    Int res;                       // return from option processing function
-
     // Initialize global and static variables
     SyCTRD = 1;
-    SyCompilePlease = 0;
+    SyCompilePlease = FALSE;
     SyDebugLoading = 0;
     SyLineEdit = 1;
-#ifdef HPCGAP
+#ifdef HAVE_LIBREADLINE
+  #ifdef HPCGAP
     SyUseReadline = 0;
-    SyNumProcessors = SyCountProcessors();
-#else
+  #else
     SyUseReadline = 1;
+  #endif
+#endif
+#ifdef HPCGAP
+    SyNumProcessors = SyCountProcessors();
 #endif
     SyNrCols = 0;
     SyNrColsLocked = 0;
@@ -568,7 +560,11 @@ void InitSystem (
     SyStorMin = 16 * sizeof(Obj) * 1024;    // in kB
     SyStorMax = 256 * sizeof(Obj) * 1024;   // in kB
 #ifdef SYS_IS_64_BIT
-  #if defined(HAVE_SYSCONF) && defined(_SC_PAGESIZE) && defined(_SC_PHYS_PAGES)
+  // According to POSIX (at least since POSIX.1-2008) unistd.h always
+  // provides _SC_PAGESIZE. However, _SC_PHYS_PAGES is not defined in POSIX
+  // (up to at least POSIX.1-2024). But it is there (and has been for a long
+  // time) in Linux, macOS, FreeBSD, OpenBSD, so we just use it.
+  #if defined(HAVE_SYSCONF)
     // Set to 3/4 of memory size (in kB), if this is larger
     Int SyStorMaxFromMem =
         (sysconf(_SC_PAGESIZE) * sysconf(_SC_PHYS_PAGES) * 3) / 4 / 1024;
@@ -586,168 +582,142 @@ void InitSystem (
 #endif // defined(USE_GASMAN)
     SyUseModule = 1;
     SyWindow = 0;
+}
 
-#ifdef USE_GASMAN
-    for (i = 0; i < 2; i++) {
-      UInt j;
-      for (j = 0; j < 7; j++) {
-        SyGasmanNumbers[i][j] = 0;
-      }
+static void ParseCommandLineOptions(int argc, const char * argv[], int phase)
+{
+    // scan the command line for options that we have to process in the kernel
+    // we just scan the whole command line looking for the keys for the
+    // options we recognise anything else will presumably be dealt with in the
+    // library
+    while (argc > 1) {
+        argv++;
+        argc--;
+        const char * opt = *argv;
+
+        // look for an option starting with '-' and skip anything else
+        if (opt[0] != '-')
+            continue;
+
+        // all options should either have the short form `-x` or the
+        // long form `--option`, reject anything else immediately
+        if (strlen(opt) != 2 && opt[1] != '-') {
+            fputs("gap: sorry, options must not be grouped '", stderr);
+            fputs(opt, stderr);
+            fputs("'.\n", stderr);
+            usage();
+        }
+
+        // check our table of options for a match...
+        int i = 0;
+        while (options[i].handler != 0) {
+            GAP_ASSERT(options[i].shortkey != 0 ||
+                       options[i].longkey[0] != 0);
+
+            // matching shortkey?
+            if (options[i].shortkey == opt[1])
+                break;
+
+            // matching long key?
+            if (opt[1] == '-' && opt[2] != 0 &&
+                !strcmp(options[i].longkey, opt + 2)) {
+                break;
+            }
+
+            i++;
+        }
+
+        if (options[i].handler == 0)
+            continue;
+
+        if (argc < 1 + options[i].minargs) {
+            Char buf[2];
+            fputs("gap: option ", stderr);
+            fputs(opt, stderr);
+            fputs(" requires at least ", stderr);
+            buf[0] = options[i].minargs + '0';
+            buf[1] = '\0';
+            fputs(buf, stderr);
+            fputs(" arguments\n", stderr);
+            usage();
+        }
+
+        if (options[i].phase == phase)
+            (*options[i].handler)(argv + 1, options[i].otherArg);
+
+        argv += options[i].minargs;
+        argc -= options[i].minargs;
+    }
+}
+
+static void InitDotGapPath(void)
+{
+    const char * home = getenv("HOME");
+    if (home == 0)
+        return;
+
+#if defined(__CYGWIN__)
+    strxcpy(DotGapPath, home, sizeof(DotGapPath));
+    strxcat(DotGapPath, "/_gap;", sizeof(DotGapPath));
+#else
+    strxcpy(DotGapPath, home, sizeof(DotGapPath));
+    strxcat(DotGapPath, "/.gap;", sizeof(DotGapPath));
+#endif
+
+    if (!IgnoreGapRC) {
+        SySetGapRootPath(DotGapPath);
+    }
+
+#if defined(__APPLE__)
+    strxcpy(DotGapPath, home, sizeof(DotGapPath));
+    strxcat(DotGapPath, "/Library/Preferences/GAP;", sizeof(DotGapPath));
+
+    if (!IgnoreGapRC) {
+        SySetGapRootPath(DotGapPath);
     }
 #endif
 
+    // get rid of trailing semicolon (which was added to ensure
+    // SySetGapRootPath prepends the path to the list of root paths)
+    DotGapPath[strlen(DotGapPath) - 1] = '\0';
+}
+
+
+void InitSystem(int argc, const char * argv[], BOOL handleSignals)
+{
+    InitSysOpts();
+
     if (handleSignals) {
         SyInstallAnswerIntr();
     }
 
-    // save the original command line for export to GAP
-    SyOriginalArgc = argc;
-    SyOriginalArgv = argv;
-
-    // scan the command line for options that we have to process in the kernel
-    // we just scan the whole command line looking for the keys for the options we recognise
-    // anything else will presumably be dealt with in the library
-    while ( argc > 1 )
-      {
-        if (argv[1][0] == '-' ) {
-
-          if ( strlen(argv[1]) != 2 && argv[1][1] != '-') {
-            fputs("gap: sorry, options must not be grouped '", stderr);
-            fputs(argv[1], stderr);
-            fputs("'.\n", stderr);
-            goto usage;
-          }
-
-
-          for (i = 0;  options[i].shortkey != argv[1][1] &&
-                       (argv[1][1] != '-' || argv[1][2] == 0 || strcmp(options[i].longkey, argv[1] + 2)) &&
-                       (options[i].shortkey != 0 || options[i].longkey[0] != 0); i++)
-            ;
-
-
-
-
-          if (argc < 2 + options[i].minargs)
-            {
-              Char buf[2];
-              fputs("gap: option ", stderr);
-              fputs(argv[1], stderr);
-              fputs(" requires at least ", stderr);
-              buf[0] = options[i].minargs + '0';
-              buf[1] = '\0';
-              fputs(buf, stderr);
-              fputs(" arguments\n", stderr);
-              goto usage;
-            }
-          if (options[i].handler) {
-            res = (*options[i].handler)(argv+2, options[i].otherArg);
-
-            switch (res)
-              {
-              case -1: goto usage;
-                // case -2: goto fullusage;
-              default: ;     // fall through and continue
-              }
-          }
-          else
-            res = options[i].minargs;
-          // recordOption(argv[1][1], res,  argv+2);
-          argv += 1 + res;
-          argc -= 1 + res;
-
-        }
-        else {
-          argv++;
-          argc--;
-        }
-
-      }
-#if !defined(HAVE_LIBREADLINE)
-    // don't use readline of readline is not available (obviously)
-    // so that e.g. the GAP banner reports this correctly.
-    SyUseReadline = 0;
-#else
-    // don't use readline if in Window mode (e.g. for XGAP)
-    if (SyWindow)
-        SyUseReadline = 0;
-    // don't use readline if stdin is not attached to a terminal
-    // FIXME: disabled this, as it breaks certain workspaces (see also
-    // issue https://github.com/gap-system/gap/issues/5014)
-    //else if (!isatty(fileno(stdin)))
-    //    SyUseReadline = 0;
-#endif
-
     InitSysFiles();
 
+    // first stage of command line options parsing: handle everything except
+    // for root paths
+    ParseCommandLineOptions(argc, argv, 0);
+
+#ifdef HAVE_LIBREADLINE
+    InitReadline();
+#endif
+
     // now that the user has had a chance to give -x and -y,
     // we determine the size of the screen ourselves
-    getwindowsize();
-
-#ifdef USE_GASMAN
-    // fix max if it is lower than min
-    if ( SyStorMax != 0 && SyStorMax < SyStorMin ) {
-        SyStorMax = SyStorMin;
-    }
-
-    // fix pool size if larger than SyStorKill
-    if ( SyStorKill != 0 && SyAllocPool != 0 &&
-                            SyAllocPool > 1024 * SyStorKill ) {
-        SyAllocPool = SyStorKill * 1024;
-    }
-#endif
+    InitWindowSize();
 
     // when running in package mode set ctrl-d and line editing
-    if ( SyWindow ) {
+    if (SyWindow) {
         SyRedirectStderrToStdOut();
-        syWinPut( 0, "@p", "1." );
+        syWinPut(0, "@p", "1.");
     }
+}
 
-    // should GAP load 'init/lib.g' on initialization
-    if ( SyCompilePlease ) {
-        SyLoadSystemInitFile = 0;
-    }
-#ifdef GAP_ENABLE_SAVELOAD
-    else if ( SyRestoring ) {
-        SyLoadSystemInitFile = 0;
-    }
-#endif
+void InitRootPaths(int argc, const char * argv[])
+{
+    SySetGapRootPath(SyDefaultRootPath);
 
-    // the users home directory
-    if ( getenv("HOME") != 0 ) {
-        strxcpy(DotGapPath, getenv("HOME"), sizeof(DotGapPath));
-# if defined(__APPLE__)
-        // On Mac OS, add .gap to the sys roots, but leave
-        // DotGapPath at $HOME/Library/Preferences/GAP
-        strxcat(DotGapPath, "/.gap;", sizeof(DotGapPath));
-        if (!IgnoreGapRC) {
-          SySetGapRootPath(DotGapPath);
-        }
+    // second stage of command line options parsing: handle root paths
+    ParseCommandLineOptions(argc, argv, 1);
 
-        strxcpy(DotGapPath, getenv("HOME"), sizeof(DotGapPath));
-        strxcat(DotGapPath, "/Library/Preferences/GAP;", sizeof(DotGapPath));
-# elif defined(__CYGWIN__)
-        strxcat(DotGapPath, "/_gap;", sizeof(DotGapPath));
-# else
-        strxcat(DotGapPath, "/.gap;", sizeof(DotGapPath));
-# endif
-
-        if (!IgnoreGapRC) {
-          SySetGapRootPath(DotGapPath);
-        }
-        DotGapPath[strlen(DotGapPath)-1] = '\0';
-    }
-
-
-    // now we start
-    return;
-
-    // print a usage message
-usage:
- fputs("usage: gap [OPTIONS] [FILES]\n", stderr);
- fputs("       run the Groups, Algorithms and Programming system, Version ", stderr);
- fputs(SyBuildVersion, stderr);
- fputs("\n", stderr);
- fputs("       use '-h' option to get help.\n", stderr);
- fputs("\n", stderr);
- SyExit( 1 );
+    InitDotGapPath();
 }
