@@ -74,7 +74,7 @@ static inline void FORGET_WP(Obj wp, UInt pos)
 *F  STORE_LEN_WPOBJ(<wp>,<len>) . . . . . . . . set the length of a WP object
 **
 **  'STORE_LEN_WPOBJ' sets the length of the WP object <wp> to <len>.
-** 
+**
 **  Objects at the end of <wp> may evaporate, so the stored length can only
 **  be regarded as an upper bound.
 */
@@ -88,7 +88,7 @@ static inline void STORE_LEN_WPOBJ(Obj wp, Int len)
 **
 *F  STORED_LEN_WPOBJ(<wp>) . . . . . . . . . . . stored length of a WP object
 **
-**  'STORED_LEN_WPOBJ' returns the stored length of the WP object <wp> 
+**  'STORED_LEN_WPOBJ' returns the stored length of the WP object <wp>
 **  as a C integer.
 **
 **  Note that as the list can mutate under your feet, the length may be
@@ -172,8 +172,8 @@ static inline void SET_ELM_WPOBJ(Obj list, UInt pos, Obj val)
 */
 static inline void GROW_WPOBJ(Obj wp, UInt need)
 {
-  UInt                plen;           /* new physical length             */
-  UInt                good;           /* good new physical length        */
+  UInt                plen;           // new physical length
+  UInt                good;           // good new physical length
 
     // if there is already enough space, do nothing
     if (need < SIZE_OBJ(wp)/sizeof(Obj))
@@ -184,10 +184,10 @@ static inline void GROW_WPOBJ(Obj wp, UInt need)
 
     // find out how large the object should become at least (we grow by
     // at least 25%, like plain lists)
-    /* find out how large the plain list should become                     */
+    // find out how large the plain list should become
     good = 5 * (SIZE_OBJ(wp)/sizeof(Obj)-1) / 4 + 4;
 
-    /* but maybe we need more                                              */
+    // but maybe we need more
     if ( need < good ) { plen = good; }
     else               { plen = need; }
 
@@ -227,17 +227,16 @@ static inline void GROW_WPOBJ(Obj wp, UInt need)
 
 static Obj FuncWeakPointerObj(Obj self, Obj list)
 {
-  Obj wp; 
+  Obj wp;
   Int i;
-  Int len; 
+  Int len;
 #ifdef USE_BOEHM_GC
-  /* We need to make sure that the list stays live until
-   * after REGISTER_WP(); on architectures that pass
-   * arguments in registers (x86_64, SPARC, etc), the
-   * argument register may be reused. In conjunction with
-   * loop unrolling, the reference to 'list' may then be
-   * destroyed before REGISTER_WP() is called.
-   */
+  // We need to make sure that the list stays live until
+  // after REGISTER_WP(); on architectures that pass
+  // arguments in registers (x86_64, SPARC, etc), the
+  // argument register may be reused. In conjunction with
+  // loop unrolling, the reference to 'list' may then be
+  // destroyed before REGISTER_WP() is called.
   volatile Obj list2 = list;
 #endif
   len = LEN_LIST(list);
@@ -245,9 +244,9 @@ static Obj FuncWeakPointerObj(Obj self, Obj list)
       ErrorMayQuit("WeakPointerObj: List size too large", 0, 0);
 
   wp = (Obj) NewBag(T_WPOBJ, (len+1)*sizeof(Obj));
-  STORE_LEN_WPOBJ(wp,len); 
-  for (i = 1; i <= len ; i++) 
-    { 
+  STORE_LEN_WPOBJ(wp,len);
+  for (i = 1; i <= len ; i++)
+    {
 #ifdef USE_BOEHM_GC
       Obj tmp = ELM0_LIST(list2, i);
       SET_ELM_WPOBJ(wp, i, tmp);
@@ -256,13 +255,13 @@ static Obj FuncWeakPointerObj(Obj self, Obj list)
 #else
       SET_ELM_WPOBJ(wp, i, ELM0_LIST(list, i));
 #endif
-      CHANGED_BAG(wp);          /* this must be here in case list is 
-                                 in fact an object and causes a GC in the 
-                                 element access method */
+      // this must be here in case list is in fact an object and causes a GC
+      // in the element access method
+      CHANGED_BAG(wp);
     }
 
-  return wp; 
-} 
+  return wp;
+}
 
 
 /****************************************************************************
@@ -272,7 +271,7 @@ static Obj FuncWeakPointerObj(Obj self, Obj list)
 **  'LengthWPObj' returns the length of the WP object <wp> as a C integer.
 **  The value cannot be trusted past a garbage collection, as trailing items
 **  may evaporate.
-**   
+**
 **  Any identifiers of trailing objects that have evaporated in a garbage
 **  collection are cleaned up by this function. However, for HPC-GAP, this
 **  only happens if we have exclusive write access.
@@ -330,10 +329,9 @@ static Obj FuncSetElmWPObj(Obj self, Obj wp, Obj pos, Obj val)
     UInt ipos = GetPositiveSmallInt(SELF_NAME, pos);
 
 #ifdef USE_BOEHM_GC
-  /* Ensure reference remains visible to GC in case val is
-   * stored in a register and the register is reused before
-   * REGISTER_WP() is called.
-   */
+  // Ensure reference remains visible to GC in case val is
+  // stored in a register and the register is reused before
+  // REGISTER_WP() is called.
   volatile Obj val2 = val;
 #endif
   if (LengthWPObj(wp)  < ipos)
@@ -365,16 +363,15 @@ static Obj FuncSetElmWPObj(Obj self, Obj wp, Obj pos, Obj val)
 **  'IsBoundElmWPObj' returns 1 is there is (currently) a live
 **  value at position pos or the WP object wp and  0 otherwise, cleaning up a
 **  dead entry if there is one
-** */
-
-
+**
+*/
 static BOOL IsBoundElmWPObj(Obj wp, UInt ipos)
 {
 #ifdef HPCGAP
   volatile
 #endif
   Obj elm;
-  if ( LengthWPObj(wp) < ipos ) 
+  if ( LengthWPObj(wp) < ipos )
     {
       return 0;
     }
@@ -410,7 +407,7 @@ static Obj FuncIsBoundElmWPObj(Obj self, Obj wp, Obj pos)
 **
 *F  FuncUnbindElmWPObj(<self>,<wp>,<pos>) . . . Unbind handler for WP objects
 **
-**  GAP  handler for Unbind on WP object. 
+**  GAP  handler for Unbind on WP object.
 */
 
 static Obj FuncUnbindElmWPObj(Obj self, Obj wp, Obj pos)
@@ -421,9 +418,8 @@ static Obj FuncUnbindElmWPObj(Obj self, Obj wp, Obj pos)
   Int len = LengthWPObj(wp);
   if ( ipos <= len ) {
 #ifdef USE_BOEHM_GC
-    /* Ensure the result is visible on the stack in case a garbage
-     * collection happens after the read.
-     */
+    // Ensure the result is visible on the stack in case a garbage
+    // collection happens after the read.
     volatile Obj tmp = ELM_WPOBJ(wp, ipos);
 #ifdef HPCGAP
     MEMBAR_READ();
@@ -486,7 +482,7 @@ static Obj ElmDefWPList(Obj wp, Int ipos, Obj def)
 **  between a  call   to IsBound and the    access. This, of  course,  causes
 **  possible  confusion  with a WP  object which  does have  a  value of fail
 **  stored in  it. This, however  can be  checked  with a subsequent  call to
-**  IsBound, relying on the fact  that fail can never  dissapear in a garbage
+**  IsBound, relying on the fact  that fail can never  disappear in a garbage
 **  collection.
 */
 static Obj FuncElmWPObj(Obj self, Obj wp, Obj pos)
@@ -533,12 +529,12 @@ static Obj FiltIsWPObj(Obj self, Obj wp)
 **  These functions are installed for GASMAN to use in garbage collection.
 **  The sweeping function must clean up any dead weak pointers encountered so
 **  that, after a full GC, the masterpointers occupied by the dead weak
-**  pointers can be reclaimed.  
+**  pointers can be reclaimed.
 */
 
 #if defined(USE_GASMAN)
 
-static void MarkWeakPointerObj(Obj wp)
+static void MarkWeakPointerObj(Obj wp, void * ref)
 {
     // can't use the stored length here, in case we are in the middle of
     // copying
@@ -562,7 +558,7 @@ static void SweepWeakPointerObj( Bag *src, Bag *dst, UInt len)
 
 #ifdef USE_JULIA_GC
 
-static void MarkWeakPointerObj(Obj wp)
+static void MarkWeakPointerObj(Obj wp, void * ref)
 {
     // can't use the stored length here, in case we are in the middle of
     // copying
@@ -570,7 +566,7 @@ static void MarkWeakPointerObj(Obj wp)
     for (UInt i = 1; i <= len; i++) {
         Bag elm = CONST_ADDR_OBJ(wp)[i];
         if (IS_BAG_REF(elm))
-            MarkJuliaWeakRef(elm);
+            MarkJuliaWeakRef(elm, ref);
     }
 }
 
@@ -629,10 +625,10 @@ static void CopyWPObj(TraversalState * traversal, Obj copy, Obj original)
 
 static Obj CopyObjWPObj(Obj obj, Int mut)
 {
-    Obj                 copy;           /* copy, result                    */
-    Obj                 tmp;            /* temporary variable              */
+    Obj                 copy;           // copy, result
+    Obj                 tmp;            // temporary variable
     Obj                 elm;
-    UInt                i;              /* loop variable                   */
+    UInt                i;              // loop variable
 
     // immutable input is handled by COPY_OBJ
     GAP_ASSERT(IS_MUTABLE_OBJ(obj));
@@ -640,7 +636,7 @@ static Obj CopyObjWPObj(Obj obj, Int mut)
     // This may get smaller if a GC occurs during copying
     UInt len = LengthWPObj(obj);
 
-    /* make a copy                                                         */
+    // make a copy
     if ( mut ) {
         copy = NewBag( T_WPOBJ, SIZE_OBJ(obj) );
         ADDR_OBJ(copy)[0] = CONST_ADDR_OBJ(obj)[0];
@@ -650,7 +646,7 @@ static Obj CopyObjWPObj(Obj obj, Int mut)
         // Set length as plist is constructed
     }
 
-    /* leave a forwarding pointer                                          */
+    // leave a forwarding pointer
     PrepareCopy(obj, copy);
 
     // copy the subvalues. Loop goes up so length of PLIST is set correctly
@@ -668,7 +664,7 @@ static Obj CopyObjWPObj(Obj obj, Int mut)
         }
     }
 
-    /* return the copy                                                     */
+    // return the copy
     return copy;
 }
 
@@ -754,10 +750,10 @@ static void MakeImmutableWPObj(Obj obj)
 */
 static void CleanObjWPObj(Obj obj)
 {
-    UInt                i;              /* loop variable                   */
-    Obj                 elm;            /* subobject                       */
+    UInt                i;              // loop variable
+    Obj                 elm;            // subobject
 
-    /* clean the subvalues                                                 */
+    // clean the subvalues
     for ( i = 1; i < SIZE_OBJ(obj)/sizeof(Obj); i++ ) {
         elm = ELM_WPOBJ(obj, i);
         if (elm)
@@ -856,9 +852,9 @@ static Int InitKernel (
     // set the bag type names (for error messages and debugging)
     InitBagNamesFromTable( BagNames );
 
-    /* install the marking and sweeping methods                            */
+    // install the marking and sweeping methods
 #if defined(USE_BOEHM_GC)
-    /* force atomic allocation of these pointers */
+    // force atomic allocation of these pointers
     InitMarkFuncBags ( T_WPOBJ,          MarkNoSubBags   );
 #elif defined(USE_GASMAN)
     InitMarkFuncBags ( T_WPOBJ,          MarkWeakPointerObj   );
@@ -866,18 +862,18 @@ static Int InitKernel (
 #elif defined(USE_JULIA_GC)
     InitMarkFuncBags ( T_WPOBJ,          MarkWeakPointerObj   );
 #else
-#error Unknown garbage collector implementation, no weak pointer object implemention available
+#error Unknown garbage collector implementation, no weak pointer object implementation available
 #endif
 
-    /* typing method                                                       */
+    // typing method
     TypeObjFuncs[ T_WPOBJ ] = TypeWPObj;
     ImportGVarFromLibrary( "TYPE_WPOBJ", &TYPE_WPOBJ );
 
-    /* init filters and functions                                          */
+    // init filters and functions
     InitHdlrFiltsFromTable( GVarFilts );
     InitHdlrFuncsFromTable( GVarFuncs );
 
-    /* saving function                                                     */
+    // saving function
 #ifdef GAP_ENABLE_SAVELOAD
     SaveObjFuncs[ T_WPOBJ ] = SaveWPObj;
     LoadObjFuncs[ T_WPOBJ ] = LoadWPObj;
@@ -889,7 +885,7 @@ static Int InitKernel (
 #ifdef USE_THREADSAFE_COPYING
     SetTraversalMethod(T_WPOBJ, TRAVERSE_BY_FUNCTION, TraverseWPObj, CopyWPObj);
 #else
-    /* copying functions                                                   */
+    // copying functions
     CopyObjFuncs[  T_WPOBJ           ] = CopyObjWPObj;
     CleanObjFuncs[ T_WPOBJ           ] = CleanObjWPObj;
 #endif
@@ -906,7 +902,7 @@ static Int InitKernel (
 static Int InitLibrary (
     StructInitInfo *    module )
 {
-    /* init filters and functions                                          */
+    // init filters and functions
     InitGVarFiltsFromTable( GVarFilts );
     InitGVarFuncsFromTable( GVarFuncs );
 
