@@ -52,7 +52,7 @@ static Obj  HdlrFunc2 (
   DoOperation2Args( CallFuncListOper, t_1, NewPlistFromArgs( t_2, t_3 ) );
  }
  
- /* Info( ... ); */
+ /* Info( InfoDebug, 2, "Do not print" ); */
  t_1 = GC_InfoDebug;
  CHECK_BOUND( t_1, "InfoDebug" );
  t_3 = InfoCheckLevel( t_1, INTOBJ_INT(2) );
@@ -65,7 +65,7 @@ static Obj  HdlrFunc2 (
   InfoDoPrint( t_1, INTOBJ_INT(2), t_2 );
  }
  
- /* Info( ... ); */
+ /* Info( InfoDebug, 1, "print this A" ); */
  t_1 = GC_InfoDebug;
  CHECK_BOUND( t_1, "InfoDebug" );
  t_3 = InfoCheckLevel( t_1, INTOBJ_INT(1) );
@@ -109,7 +109,7 @@ static Obj  HdlrFunc2 (
   DoOperation2Args( CallFuncListOper, t_1, NewPlistFromArgs( t_2, t_3 ) );
  }
  
- /* Info( ... ); */
+ /* Info( InfoDebug, 3, "Do not print" ); */
  t_1 = GC_InfoDebug;
  CHECK_BOUND( t_1, "InfoDebug" );
  t_3 = InfoCheckLevel( t_1, INTOBJ_INT(3) );
@@ -122,7 +122,7 @@ static Obj  HdlrFunc2 (
   InfoDoPrint( t_1, INTOBJ_INT(3), t_2 );
  }
  
- /* Info( ... ); */
+ /* Info( InfoDebug, 2, "print this B" ); */
  t_1 = GC_InfoDebug;
  CHECK_BOUND( t_1, "InfoDebug" );
  t_3 = InfoCheckLevel( t_1, INTOBJ_INT(2) );
@@ -135,7 +135,7 @@ static Obj  HdlrFunc2 (
   InfoDoPrint( t_1, INTOBJ_INT(2), t_2 );
  }
  
- /* Info( ... ); */
+ /* Info( InfoDebug, 1, "print ", "this ", "C" ); */
  t_1 = GC_InfoDebug;
  CHECK_BOUND( t_1, "InfoDebug" );
  t_3 = InfoCheckLevel( t_1, INTOBJ_INT(1) );
@@ -157,10 +157,6 @@ static Obj  HdlrFunc2 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 1 */
@@ -197,10 +193,6 @@ static Obj  HdlrFunc1 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* 'PostRestore' restore gvars, rnams, functions */
